External Applications
=====================

In addition to the features included in ``django-tag-fields`` directly, there are a
number of external applications which provide additional features that may be
of interest.

.. note::

    Despite their mention here, the following applications are in no way
    official, nor have they in any way been reviewed or tested.

    These applications are specific to django-taggit and will continue to perform
    in django-tag-fields in the same manner as django-taggit.

If you have an application that you'd like to see listed here, simply fork
`django-tag-fields on github <https://github.com/imAsparky/django-tag-fields>`_,
add it to this list, and send a pull request.


 * `django-taggit-anywhere <https://github.com/bashu/django-taggit-anywhere>`_:
   Simpler approach to tagging with ``taggit``. Additionally this
   project provides easy-to-use integration with ``django-taggit-helpers`` and
   ``django-taggit-labels``.
 * `django-taggit-helpers <https://github.com/mfcovington/django-taggit-helpers>`_:
   Makes it easier to work with admin pages of models
   associated with ``taggit`` tags by adding helper classes: ``TaggitCounter``,
   ``TaggitListFilter``, ``TaggitStackedInline``, ``TaggitTabularInline``.
 * `django-taggit-labels <https://github.com/bennylope/django-taggit-labels>`_:
   Provides a clickable label widget for the
   Django admin for user friendly selection from managed tag sets.
 * `django-taggit-serializer <https://github.com/glemmaPaul/django-taggit-serializer>`_:
   Adds functionality for using ``taggit`` with
   ``django-rest-framework``.
 * `django-taggit-suggest <https://github.com/frankwiles/django-taggit-suggest>`_:
   Provides support for defining keyword and regular
   expression rules for suggesting new tags for content.  This used to be
   available at ``taggit.contrib.suggest``.
 * `django-taggit-templatetags <https://github.com/feuervogel/django-taggit-templatetags>`_:
   Provides several templatetags, including one
   for tag clouds, to expose various ``taggit`` APIs directly to templates.
 * `django-taggit-bulk <https://github.com/nnseva/django-taggit-bulk>`_:
   An admin action for the bulk tagging from the model  admin instance list view.
